# NcatBot

---
![img.png](https://socialify.git.ci/liyihao1110/NcatBot/image?description=1&forks=1&issues=1&language=1&logo=https%3A%2F%2Fa.imgckr.com%2F2024%2F12%2F29%2FJO1OJ.png&name=1&owner=1&pulls=1&stargazers=1&theme=Auto)
<h2 align="center">基于 NapCat 的 QQ 机器人 Python 快速开发框架 (SDK)</h2>
<p align="center">
	<a href="https://pypi.org/project/ncatbot/"><img src="https://img.shields.io/pypi/v/ncatbot"></a>
	<a href="https://gitee.com/y_project/RuoYi-Vue/blob/master/LICENSE"><img src="https://img.shields.io/github/license/mashape/apistatus.svg"></a>
    <a href="https://qm.qq.com/q/CHbzJ2LH4k"><img src="https://img.shields.io/badge/官方群聊-201487478-brightgreen.svg"></a>
    <a href="https://qm.qq.com/q/S2zIli2qsu"><img src="https://img.shields.io/badge/基于ncatbot开发的小机器人-3786498591-brightgreen.svg"></a>
    <a href="https://pd.qq.com/s/gkpfebfim"><img src="https://img.shields.io/badge/官方频道-pd46469618-brightgreen.svg"></a>
</p>

NcatBot 是 **[NapCat](https://github.com/NapNeko/NapCatQQ)** 的 Python SDK, 它提供了一套方便易用的 Python 接口用于开发基于 NapCat 的项目——也就是 QQ 机器人.

NcatBot 同时提供针对非开发者用户的一键部署方案, 详情请前往 [NcatBot Plugins Edition](https://github.com/Isaaczhr/plugins.ncatbot.xyz).

## 如何使用

请**认真阅读**[文档](https://docs.ncatbot.xyz/), **严格**按照文档中说明正确安装和使用 NcatBot.

## 更新进度

---
[![木子/ncatbot](https://gitee.com/li-yihao0328/nc_bot/widgets/widget_card.svg?colors=ffffff,1e252b,323d47,455059,d7deea,99a0ae)](https://gitee.com/li-yihao0328/nc_bot)

## 欢迎来玩

[是 QQ 群哦喵~](https://qm.qq.com/q/L6XGXYqL86)

## 获取帮助

- 遇到任何困难时, 请先按照以下顺序尝试自己解决:
  1. **仔细阅读**[文档](https://docs.ncatbot.xyz/).
  2. 询问 [DeepSeek](https://chat.deepseek.com), [Kimi](https://kimi.ai) 等人工智能.
  3. 搜索本项目的 [Issue 列表](https://github.com/liyihao1110/ncatbot/issues).

- 如果以上方法都无法解决你的问题, 那么:

  也可以[进群](https://qm.qq.com/q/L6XGXYqL86)提问.

## 联系我们

作者: [最可爱的木子喵~](https://gitee.com/li-yihao0328)

邮箱: yihaoli_2002@foxmail.com


## 贡献者们

---
<a href="https://github.com/liyihao1110/ncatbot/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=liyihao1110/ncatbot" />
</a>

如果你有好的 Idea, 欢迎提 Issue 和 PR!

## 致谢

---
感谢 [NapCat](https://github.com/NapNeko/NapCatQQ).
